# InferenceFeedbackTarget


## Enum

* `CONTEXT` (value: `'context'`)

* `RESPONSE_RESULTS` (value: `'response_results'`)

* `PROMPT_RESULTS` (value: `'prompt_results'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


